@@ -151,29 +151,26 @@ class da:
             worldFilePath = f"{savePath}/{imgName}{imgIndex}.{worldFileType}"
         image = np.frombuffer(img, dtype="uint8")
         image = cv2.imdecode(image, cv2.IMREAD_UNCHANGED)
-        image = cv2.imencode("."+imgType, image)[1]
-        image = image.tobytes()
-        try:
-            with open(imgPath, 'wb') as f:
-                f.write(image)
+        img = cv2.imencode("."+imgType, image)[1]
+        img = img.tobytes()
+        with open(imgPath, 'wb') as f:
+                f.write(img)
                 f.flush()
-            if worldFile and boundary:
-                height, width, channels = image.shape
-                with open(worldFilePath, 'w') as f:
-                    f.write(str(Decimal((boundary.east - boundary.west)/width)))
-                    f.write("\n")
-                    f.write(str(0.0))
-                    f.write("\n")
-                    f.write(str(0.0))
-                    f.write("\n")
-                    f.write(str(Decimal((boundary.south - boundary.north)/height)))
-                    f.write("\n")
-                    f.write(str(boundary.west))
-                    f.write("\n")
-                    f.write(str(boundary.north))
-                    f.close()
-        except:
-            return False
+        if worldFile and boundary:
+            height, width, channels = image.shape
+            with open(worldFilePath, 'w') as worldFile:
+                worldFile.write(str(float((boundary.east - boundary.west)/width)))
+                worldFile.write("\n")
+                worldFile.write(str(0.0))
+                worldFile.write("\n")
+                worldFile.write(str(0.0))
+                worldFile.write("\n")
+                worldFile.write(str(float((boundary.south - boundary.north)/height)))
+                worldFile.write("\n")
+                worldFile.write(str(boundary.west))
+                worldFile.write("\n")
+                worldFile.write(str(boundary.north))
+                worldFile.close()
         return True
 
     @staticmethod
